#include <lib/std.mi>

Function stopScreen();
Function playScreen();
Function pauseScreen();
Function newSetVolume(int x, int y);

Global Group thisGroup;
Global Button playButton, pauseButton;
Global AnimatedLayer screenAnim, volumeLayer;
Global Layer posLayer;
Global Int volFlag, oldVolume;
Global Map volmap, posmap;
Global Timer posTimer;

stopScreen() {
  screenAnim.stop();
  screenAnim.gotoFrame(0);
}

pauseScreen() {
  screenAnim.pause();
}

playScreen() {
  screenAnim.play();
}

newSetVolume(int x, int y) {
  int val = volmap.getValue(x, y);

  if(val > oldvolume + 20) return;
  if(val < oldvolume - 20) return;

  setvolume(val);
}

System.onScriptLoaded() {
  thisGroup = getScriptGroup();

  volmap = new map;
  volmap.loadmap("player.volume.map");
  posmap = new map;
  posmap.loadmap("player.pos.map");

  playButton = thisGroup.getObject("play_n");
  pauseButton = thisGroup.getObject("pause_n");
  screenAnim = thisGroup.getObject("screen.animation");
  volumeLayer = thisGroup.getObject("volume.layer");
  posLayer = thisGroup.getObject("posbar");

  posTimer = new timer;
  postimer.setDelay(333);
  postimer.start();

  volFlag = 0;
  oldvolume = getVolume();
  onVolumeChanged(oldvolume);

  if(getStatus() == STATUS_PLAYING) {
    playButton.hide();
    pauseButton.show();
    playScreen();
  } else {
    playButton.show();
    pauseButton.hide();
    stopScreen();
  }
}

System.onPlay() {
  playButton.hide();
  pauseButton.show();
  playScreen();
}

System.onResume() {
  playButton.hide();
  pauseButton.show();
  playScreen();
}

System.onPause() {
  playButton.show();
  pauseButton.hide();
  pauseScreen();
}

System.onStop() {
  playButton.show();
  pauseButton.hide();
  stopScreen();
}

volumeLayer.onLeftButtonDown(int x, int y) {
  volFlag = 1;

  //newSetVolume(x - volumeLayer.getLeft(), y - volumeLayer.getTop());
}

volumeLayer.onLeftButtonUp(int x, int y) {
  volFlag = 0;
}

volumeLayer.onMouseMove(int x, int y) {
  if(volFlag == 1) {
    newSetVolume(x - volumeLayer.getLeft(), y - volumeLayer.getTop());
  }
}

System.onVolumeChanged(int val) {
  int f = val / 15;

  if(f > 16) f = 16;

  volumeLayer.gotoFrame(f);

  oldvolume = val;
}

postimer.onTimer() {
  System.onSeek(getPosition());
}

System.onSeek(int newpos) {
  if (newpos <= 0) {
    posLayer.setRegionFromMap(posmap,0,1);
    return;
  }
  int len = getPlayItemLength();
  if(len <= 0) return;
  int devby = len/255;
  if(devby <= 0) return;
  posLayer.setRegionFromMap(posmap,newpos/devby,1);
}